# bpod-modules-ibl

A Python library for accessing Bpod modules used at IBL

---
[![CI](https://github.com/int-brain-lab/bpod-modules-ibl/actions/workflows/main.yaml/badge.svg)](https://github.com/int-brain-lab/bpod-modules-ibl/actions/workflows/main.yaml)
[![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/)
[![Coverage Status](https://coveralls.io/repos/github/int-brain-lab/bpod-modules-ibl/badge.svg?branch=main)](https://coveralls.io/github/int-brain-lab/bpod-modules-ibl?branch=main)
[![License](https://img.shields.io/github/license/int-brain-lab/bpod-modules-ibl)](https://github.com/int-brain-lab/bpod-modules-ibl/blob/main/LICENSE)
[![GitHub tag](https://img.shields.io/github/v/tag/int-brain-lab/bpod-modules-ibl)](https://github.com/int-brain-lab/bpod-modules-ibl/tags)
[![PyPI](https://img.shields.io/pypi/v/bpod-modules-ibl)](https://pypi.org/project/bpod-modules-ibl/)
